@@ -306,7 +306,7 @@ go_gtk_file_sel_dialog (GtkWindow *toplevel, GtkWidget *w)
 	delete_handler = g_signal_connect (w, "delete_event",
 		G_CALLBACK (gu_delete_handler), NULL);
 
-	gtk_widget_show_all (w);
+	gtk_widget_show (w);
 	gtk_grab_add (w);
 	gtk_main ();
 
@@ -591,6 +591,11 @@ gui_get_image_save_info (GtkWindow *toplevel, GSList *supported_formats,
 			gtk_widget_hide (widget);
 		}
 
+		if (supported_formats != NULL && ret_format != NULL) {
+			widget = glade_xml_get_widget (gui, "image_save_dialog_extra");
+			gtk_file_chooser_set_extra_widget (fsel, widget);
+		}
+
 		/* Export setting expander */
 		expander = glade_xml_get_widget (gui, "export_expander");
 		if (resolution != NULL) {
@@ -601,9 +606,6 @@ gui_get_image_save_info (GtkWindow *toplevel, GSList *supported_formats,
 			gtk_widget_hide (expander);
 
 		if (resolution != NULL && supported_formats != NULL && ret_format != NULL) {
-			widget = glade_xml_get_widget (gui, "image_save_dialog_extra");
-			gtk_file_chooser_set_extra_widget (fsel, widget);
-
 			resolution_table = glade_xml_get_widget (gui, "resolution_table");
 		
 			cb_format_combo_changed (format_combo, resolution_table);	
@@ -978,6 +980,120 @@ go_pixbuf_new_from_file (char const *filename)
 	return pixbuf;
 }
 
+#ifndef HAVE_GDK_CAIRO_SET_SOURCE_PIXBUF 
+/* This is public from 2.8 onwards.   */
+static void
+gdk_cairo_set_source_pixbuf (cairo_t   *cr,
+			     GdkPixbuf *pixbuf,
+			     double     pixbuf_x,
+			     double     pixbuf_y)
+{
+  gint width = gdk_pixbuf_get_width (pixbuf);
+  gint height = gdk_pixbuf_get_height (pixbuf);
+  guchar *gdk_pixels = gdk_pixbuf_get_pixels (pixbuf);
+  int gdk_rowstride = gdk_pixbuf_get_rowstride (pixbuf);
+  int n_channels = gdk_pixbuf_get_n_channels (pixbuf);
+  guchar *cairo_pixels;
+  cairo_format_t format;
+  cairo_surface_t *surface;
+  static const cairo_user_data_key_t key;
+  int j;
+
+  if (n_channels == 3)
+    format = CAIRO_FORMAT_RGB24;
+  else
+    format = CAIRO_FORMAT_ARGB32;
+
+  cairo_pixels = g_malloc (4 * width * height);
+  surface = cairo_image_surface_create_for_data ((unsigned char *)cairo_pixels,
+						 format,
+						 width, height, 4 * width);
+  cairo_surface_set_user_data (surface, &key,
+			       cairo_pixels, (cairo_destroy_func_t)g_free);
+
+  for (j = height; j; j--)
+    {
+      guchar *p = gdk_pixels;
+      guchar *q = cairo_pixels;
+
+      if (n_channels == 3)
+	{
+	  guchar *end = p + 3 * width;
+	  
+	  while (p < end)
+	    {
+#if G_BYTE_ORDER == G_LITTLE_ENDIAN
+	      q[0] = p[2];
+	      q[1] = p[1];
+	      q[2] = p[0];
+#else	  
+	      q[1] = p[0];
+	      q[2] = p[1];
+	      q[3] = p[2];
+#endif
+	      p += 3;
+	      q += 4;
+	    }
+	}
+      else
+	{
+	  guchar *end = p + 4 * width;
+	  guint t1,t2,t3;
+	    
+#define MULT(d,c,a,t) G_STMT_START { t = c * a + 0x7f; d = ((t >> 8) + t) >> 8; } G_STMT_END
+
+	  while (p < end)
+	    {
+#if G_BYTE_ORDER == G_LITTLE_ENDIAN
+	      MULT(q[0], p[2], p[3], t1);
+	      MULT(q[1], p[1], p[3], t2);
+	      MULT(q[2], p[0], p[3], t3);
+	      q[3] = p[3];
+#else	  
+	      q[0] = p[3];
+	      MULT(q[1], p[0], p[3], t1);
+	      MULT(q[2], p[1], p[3], t2);
+	      MULT(q[3], p[2], p[3], t3);
+#endif
+	      
+	      p += 4;
+	      q += 4;
+	    }
+	  
+#undef MULT
+	}
+
+      gdk_pixels += gdk_rowstride;
+      cairo_pixels += 4 * width;
+    }
+
+  cairo_set_source_surface (cr, surface, pixbuf_x, pixbuf_y);
+  cairo_surface_destroy (surface);
+}
+#endif
+
+/**
+ * go_cairo_set_source_pixbuf:
+ * @cr: a #Cairo context
+ * @pixbuf: a #GdkPixbuf
+ * @pixbuf_x: X coordinate of location to place upper left corner of @pixbuf
+ * @pixbuf_y: Y coordinate of location to place upper left corner of @pixbuf
+ * 
+ * Sets the given pixbuf as the source pattern for the Cairo context.
+ * The pattern has an extend mode of %CAIRO_EXTEND_NONE and is aligned
+ * so that the origin of @pixbuf is @pixbuf_x, @pixbuf_y
+ *
+ **/
+void
+go_cairo_set_source_pixbuf (cairo_t   *cr,
+			    GdkPixbuf *pixbuf,
+			    double     pixbuf_x,
+			    double     pixbuf_y)
+{
+	gdk_cairo_set_source_pixbuf (cr, pixbuf, pixbuf_x, pixbuf_y);
+}
+
+
 #ifndef HAVE_GTK_DIALOG_GET_RESPONSE_FOR_WIDGET
 /* This is public from 2.8 onwards.   */
 static gint
