@@ -1,6 +1,6 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * go-gui-utils.h - Misc GTK+ utilities
+ * goffice-gtk.h - Misc GTK+ utilities
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
+ * USA.
  */
 #ifndef _GOFFICE_GTK_H_
 #define _GOFFICE_GTK_H_
@@ -23,17 +23,11 @@
 #include <glade/glade-xml.h>
 #include <gtk/gtkfilechooser.h>
 #include <goffice/app/goffice-app.h>
+#include <goffice/utils/go-image.h>
 
 G_BEGIN_DECLS
 
-typedef struct {
-	char *name;
-	char *desc;
-	char *ext;
-	gboolean has_pixbuf_saver;
-} GOImageType;
-
-void	   go_editable_enters (GtkWindow *window, GtkWidget *w);
+void	   go_gtk_editable_enters (GtkWindow *window, GtkWidget *w);
 
 GladeXML  *go_libglade_new (char const *gladefile, char const *root,
 			    char const *domain, GOCmdContext *cc);
@@ -41,12 +35,18 @@ GladeXML  *go_libglade_new (char const *gladefile, char const *root,
 GdkPixbuf *go_pixbuf_new_from_file	(char const *filename);
 GdkPixbuf *go_pixbuf_intelligent_scale	(GdkPixbuf *pixbuf, 
 					 guint width, guint height);
+void       go_cairo_set_source_pixbuf (cairo_t   *cr,
+				       GdkPixbuf *pixbuf,
+				       double     pixbuf_x,
+				       double     pixbuf_y);
 
 int	   go_pango_measure_string	(PangoContext *context,
 					 PangoFontDescription const *font_desc,
 					 char const *str);
 
 gint       go_gtk_dialog_run		(GtkDialog *dialog, GtkWindow *parent);
+GtkWidget *go_gtk_dialog_add_button	(GtkDialog *dialog, char const *text, char const *stock_id,
+					 gint response_id);
 void       go_gtk_notice_dialog		(GtkWindow *parent, GtkMessageType type, 
 					 const gchar *format, ...);
 void       go_gtk_notice_nonmodal_dialog (GtkWindow *parent, GtkWidget **ref,
@@ -63,15 +63,16 @@ void	   go_gtk_help_button_init	(GtkWidget *w, char const *data_dir,
 void       go_gtk_nonmodal_dialog	(GtkWindow *toplevel, GtkWindow *dialog);
 gboolean   go_gtk_file_sel_dialog	(GtkWindow *toplevel, GtkWidget *w);
 char	  *go_gtk_select_image		(GtkWindow *toplevel, const char *initial);
-char	  *gui_get_image_save_info	(GtkWindow *toplevel, GSList *formats, 
-					 GOImageType const **ret_format);
-char *go_mime_to_image_format     (char const *mime_type);
-char *go_image_format_to_mime     (char const *format);
+char      *gui_get_image_save_info 	(GtkWindow *toplevel, GSList *supported_formats,
+					 GOImageFormat *ret_format, double *dpi);
+
 gboolean   go_gtk_url_is_writeable	(GtkWindow *parent, char const *url,
 					 gboolean overwrite_by_default);
 
 void	   go_atk_setup_label	 	(GtkWidget *label, GtkWidget *target);
 
+void       go_dialog_guess_alternative_button_order (GtkDialog *dialog);
+
 G_END_DECLS
 
 #endif /* _GOFFICE_GTK_H_ */
